package org.jeecg.modules.itdmDevice.controller;

import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.itdmDevice.entity.ItdmDevice;
import org.jeecg.modules.itdmDevice.service.IItdmDeviceService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 设备表
 * @Author: jeecg-boot
 * @Date:   2023-05-20
 * @Version: V1.0
 */
@Api(tags="设备表")
@RestController
@RequestMapping("/itdmDevice/itdmDevice")
@Slf4j
public class ItdmDeviceController extends JeecgController<ItdmDevice, IItdmDeviceService> {
	@Autowired
	private IItdmDeviceService itdmDeviceService;

	 /**
	  * 设备列表
	  */
	 @ApiOperation(value="设备下拉列表", notes="设备下拉列表")
	 @GetMapping("/xialalist")
	 public List<ItdmDevice> list1()
	 {
		 List<ItdmDevice> list = itdmDeviceService.queryList();
		 return list;
	 }


	/**
	 * 分页列表查询
	 *
	 * @param itdmDevice
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "设备表-分页列表查询")
	@ApiOperation(value="设备表-分页列表查询", notes="设备表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<ItdmDevice>> queryPageList(ItdmDevice itdmDevice,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<ItdmDevice> queryWrapper = QueryGenerator.initQueryWrapper(itdmDevice, req.getParameterMap());
		Page<ItdmDevice> page = new Page<ItdmDevice>(pageNo, pageSize);
		IPage<ItdmDevice> pageList = itdmDeviceService.page(page, queryWrapper);
		return Result.OK(pageList);
	}

	/**
	 *   添加
	 *
	 * @param itdmDevice
	 * @return
	 */
	@AutoLog(value = "设备表-添加")
	@ApiOperation(value="设备表-添加", notes="设备表-添加")
	//@RequiresPermissions("org.jeecg.modules:itdm_device:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody ItdmDevice itdmDevice) {
		itdmDeviceService.save(itdmDevice);
		return Result.OK("添加成功！");
	}

	/**
	 *  编辑
	 *
	 * @param itdmDevice
	 * @return
	 */
	 @AutoLog(value = "设备表-编辑")
	 @ApiOperation(value="设备表-编辑", notes="设备表-编辑")
	 //@RequiresPermissions("org.jeecg.modules:itdm_device:edit")
	 @RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	 public Result<String> edit(@RequestBody ItdmDevice itdmDevice) {
		 ItdmDevice itdmDeviceYuan = itdmDeviceService.getById(itdmDevice.getId());
		 Date date_now = itdmDevice.getRepairTime();
		 Date date_yuan = itdmDeviceYuan.getRepairTime();
		 if(date_now == null){
			 itdmDevice.setIsRepair(0);  //传来的维护时间为空，需将维护状态改为未维护
		 }else if( !date_now.equals(date_yuan)){ //两个维护时间不同，说明重新输入了维护时间，需将维护状态改为未维护
			 itdmDevice.setIsRepair(0);
		 }
		 itdmDeviceService.updateById(itdmDevice);
		 return Result.OK("编辑成功!");
	 }

	 /**
	  *  编辑2——仅修改设备状态故障、非故障
	  */
	 @AutoLog(value = "设备表-编辑2仅修改设备状态故障、非故障")
	 @ApiOperation(value="设备表-编辑2仅修改设备状态故障、非故障", notes="设备表-编辑2仅修改设备状态故障、非故障")
	 //@RequiresPermissions("org.jeecg.modules:itdm_device:edit1")
	 @RequestMapping(value = "/edit1", method = {RequestMethod.PUT,RequestMethod.POST})
	 public Result<String> edit1(@RequestBody ItdmDevice itdmDevice) {
		 ItdmDevice itdmDeviceNew = new ItdmDevice();
		 itdmDeviceNew.setId(itdmDevice.getId());
		 itdmDeviceNew.setDeviceStatus(itdmDevice.getDeviceStatus());
		 itdmDeviceService.updateById(itdmDevice);
		 return Result.OK("编辑成功!");
	 }

	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "设备表-通过id删除")
	@ApiOperation(value="设备表-通过id删除", notes="设备表-通过id删除")
	//@RequiresPermissions("org.jeecg.modules:itdm_device:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		itdmDeviceService.removeById(id);
		return Result.OK("删除成功!");
	}

	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "设备表-批量删除")
	@ApiOperation(value="设备表-批量删除", notes="设备表-批量删除")
	//@RequiresPermissions("org.jeecg.modules:itdm_device:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.itdmDeviceService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}

	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "设备表-通过id查询")
	@ApiOperation(value="设备表-通过id查询", notes="设备表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<ItdmDevice> queryById(@RequestParam(name="id",required=true) String id) {
		ItdmDevice itdmDevice = itdmDeviceService.getById(id);
		if(itdmDevice==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(itdmDevice);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param itdmDevice
    */
    //@RequiresPermissions("org.jeecg.modules:itdm_device:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ItdmDevice itdmDevice) {
        return super.exportXls(request, itdmDevice, ItdmDevice.class, "设备表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    //@RequiresPermissions("itdm_device:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ItdmDevice.class);
    }

}
