package org.jeecg.modules.weituo.controller;

import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.weituo.dto.WeituoInsertCommand;
import org.jeecg.modules.weituo.dto.WeituoUpdateCommand;
import org.jeecg.modules.weituo.entity.ItdmWeituoInfo;
import org.jeecg.modules.weituo.service.IItdmWeituoInfoService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.weituo.vo.ItdmWeituoInfoInfoVO;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 委托信息
 * @Author: jeecg-boot
 * @Date:   2023-05-17
 * @Version: V1.0
 */
@Api(tags="委托信息")
@RestController
@RequestMapping("/weituo/itdmWeituoInfo")
@Slf4j
public class ItdmWeituoInfoController extends JeecgController<ItdmWeituoInfo, IItdmWeituoInfoService> {
	@Autowired
	private IItdmWeituoInfoService itdmWeituoInfoService;
	
	/**
	 * 分页列表查询
	 *
	 * @param itdmWeituoInfo
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "委托信息-分页列表查询")
	@ApiOperation(value="委托信息-分页列表查询", notes="委托信息-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<ItdmWeituoInfo>> queryPageList(ItdmWeituoInfo itdmWeituoInfo,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<ItdmWeituoInfo> queryWrapper = QueryGenerator.initQueryWrapper(itdmWeituoInfo, req.getParameterMap());
		Page<ItdmWeituoInfo> page = new Page<ItdmWeituoInfo>(pageNo, pageSize);
		IPage<ItdmWeituoInfo> pageList = itdmWeituoInfoService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param itdmWeituoInfo
	 * @return
	 */
	@AutoLog(value = "委托信息-添加")
	@ApiOperation(value="委托信息-添加", notes="委托信息-添加")
	//@RequiresPermissions("org.jeecg.modules:itdm_weituo_info:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody WeituoInsertCommand itdmWeituoInfo) {
		itdmWeituoInfoService.saveWeituo(itdmWeituoInfo);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param itdmWeituoInfo
	 * @return
	 */
	@AutoLog(value = "委托信息-编辑")
	@ApiOperation(value="委托信息-编辑", notes="委托信息-编辑")
	//@RequiresPermissions("org.jeecg.modules:itdm_weituo_info:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody WeituoUpdateCommand itdmWeituoInfo) {
		itdmWeituoInfoService.updateWeituo(itdmWeituoInfo);

		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "委托信息-通过id删除")
	@ApiOperation(value="委托信息-通过id删除", notes="委托信息-通过id删除")
	//@RequiresPermissions("org.jeecg.modules:itdm_weituo_info:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		itdmWeituoInfoService.deleteById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "委托信息-批量删除")
	@ApiOperation(value="委托信息-批量删除", notes="委托信息-批量删除")
	//@RequiresPermissions("org.jeecg.modules:itdm_weituo_info:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.itdmWeituoInfoService.deleteByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "委托信息-通过id查询")
	@ApiOperation(value="委托信息-通过id查询", notes="委托信息-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<ItdmWeituoInfoInfoVO> queryById(@RequestParam(name="id",required=true) String id) {
		ItdmWeituoInfoInfoVO itdmWeituoInfo = itdmWeituoInfoService.findById(id);
		if(itdmWeituoInfo==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(itdmWeituoInfo);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param itdmWeituoInfo
    */
    //@RequiresPermissions("org.jeecg.modules:itdm_weituo_info:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ItdmWeituoInfo itdmWeituoInfo) {
        return super.exportXls(request, itdmWeituoInfo, ItdmWeituoInfo.class, "委托信息");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    //@RequiresPermissions("itdm_weituo_info:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ItdmWeituoInfo.class);
    }
	 @AutoLog(value = "添加或编辑委托信息")
	 @ApiOperation(value = "添加或编辑委托信息", notes = "添加或编辑委托信息")
	 @RequestMapping("/saveOrUpdateWeituo")
	 public Result<String> saveOrUpdateWeituo(@RequestBody ItdmWeituoInfo weituoInfo) {
		 try {
			 if (StringUtils.isBlank(weituoInfo.getId())) { // 添加
				 weituoInfo.setCreateTime(new Date());
				 weituoInfo.setShenheStatus("待审核"); // 初始状态为待审核
				 itdmWeituoInfoService.save(weituoInfo); // 调用 service 的保存方法
			 } else { // 编辑
				 ItdmWeituoInfo oldWeituo = itdmWeituoInfoService.getById(weituoInfo.getId());
				 if (oldWeituo == null) {
					 return Result.error("未找到对应数据");
				 }
				 // 这里只修改一些需要修改的属性，其他属性不变
				 oldWeituo.setShenheStatus(weituoInfo.getShenheStatus());
				 oldWeituo.setShenheMsg(weituoInfo.getShenheMsg());
				 oldWeituo.setShenheTime((new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date())));

				 // 需要根据业务逻辑进行判断
				 if ("审核通过".equals(oldWeituo.getShenheStatus())) {
					 oldWeituo.setUpdateTime(new Date());
				 }

				 itdmWeituoInfoService.updateById(oldWeituo); // 调用 service 的更新方法
			 }

			 return Result.OK("操作成功！");
		 } catch (Exception e) {
			 log.error("添加或编辑委托信息出错！", e);
			 return Result.error("操作失败！");
		 }
	 }

}
